@@ -1,6 +1,6 @@
 /* Output the generated parsing program for Bison.
 
-   Copyright (C) 1984, 1986, 1989, 1992, 2000-2015 Free Software
+   Copyright (C) 1984, 1986, 1989, 1992, 2000-2015, 2018 Free Software
    Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
@@ -64,13 +64,10 @@ Name (char const *name,                                                 \
 {                                                                       \
   Type min = first;                                                     \
   Type max = first;                                                     \
-  long int lmin;                                                        \
-  long int lmax;                                                        \
-  int i;                                                                \
   int j = 1;                                                            \
                                                                         \
   obstack_printf (&format_obstack, "%6d", first);                       \
-  for (i = begin; i < end; ++i)                                         \
+  for (int i = begin; i < end; ++i)                                     \
     {                                                                   \
       obstack_1grow (&format_obstack, ',');                             \
       if (j >= 10)                                                      \
@@ -88,8 +85,8 @@ Name (char const *name,                                                 \
     }                                                                   \
   muscle_insert (name, obstack_finish0 (&format_obstack));              \
                                                                         \
-  lmin = min;                                                           \
-  lmax = max;                                                           \
+  long lmin = min;                                                      \
+  long lmax = max;                                                      \
   /* Build 'NAME_min' and 'NAME_max' in the obstack. */                 \
   obstack_printf (&format_obstack, "%s_min", name);                     \
   MUSCLE_INSERT_LONG_INT (obstack_finish0 (&format_obstack), lmin);     \
@@ -97,7 +94,7 @@ Name (char const *name,                                                 \
   MUSCLE_INSERT_LONG_INT (obstack_finish0 (&format_obstack), lmax);     \
 }
 
-GENERATE_MUSCLE_INSERT_TABLE (muscle_insert_unsigned_int_table, unsigned int)
+GENERATE_MUSCLE_INSERT_TABLE (muscle_insert_unsigned_int_table, unsigned)
 GENERATE_MUSCLE_INSERT_TABLE (muscle_insert_int_table, int)
 GENERATE_MUSCLE_INSERT_TABLE (muscle_insert_base_table, base_number)
 GENERATE_MUSCLE_INSERT_TABLE (muscle_insert_rule_number_table, rule_number)
@@ -149,7 +146,7 @@ prepare_symbols (void)
   MUSCLE_INSERT_INT ("tokens_number", ntokens);
   MUSCLE_INSERT_INT ("nterms_number", nvars);
   MUSCLE_INSERT_INT ("symbols_number", nsyms);
-  MUSCLE_INSERT_INT ("undef_token_number", undeftoken->number);
+  MUSCLE_INSERT_INT ("undef_token_number", undeftoken->content->number);
   MUSCLE_INSERT_INT ("user_token_number_max", max_user_token_number);
 
   muscle_insert_symbol_number_table ("translate",
@@ -159,13 +156,12 @@ prepare_symbols (void)
 
   /* tname -- token names.  */
   {
-    int i;
     /* We assume that the table will be output starting at column 2. */
     int j = 2;
     struct quoting_options *qo = clone_quoting_options (0);
     set_quoting_style (qo, c_quoting_style);
     set_quoting_flags (qo, QA_SPLIT_TRIGRAPHS);
-    for (i = 0; i < nsyms; i++)
+    for (int i = 0; i < nsyms; i++)
       {
         char *cp = quotearg_alloc (symbols[i]->tag, -1, qo);
         /* Width of the next token, including the two quotes, the
@@ -194,10 +190,9 @@ prepare_symbols (void)
 
   /* Output YYTOKNUM. */
   {
-    int i;
     int *values = xnmalloc (ntokens, sizeof *values);
-    for (i = 0; i < ntokens; ++i)
-      values[i] = symbols[i]->user_token_number;
+    for (int i = 0; i < ntokens; ++i)
+      values[i] = symbols[i]->content->user_token_number;
     muscle_insert_int_table ("toknum", values,
                              values[0], 1, ntokens);
     free (values);
@@ -213,15 +208,14 @@ prepare_symbols (void)
 static void
 prepare_rules (void)
 {
-  unsigned int *rline = xnmalloc (nrules, sizeof *rline);
+  unsigned *rline = xnmalloc (nrules, sizeof *rline);
   symbol_number *r1 = xnmalloc (nrules, sizeof *r1);
-  unsigned int *r2 = xnmalloc (nrules, sizeof *r2);
+  unsigned *r2 = xnmalloc (nrules, sizeof *r2);
   int *dprec = xnmalloc (nrules, sizeof *dprec);
   int *merger = xnmalloc (nrules, sizeof *merger);
   int *immediate = xnmalloc (nrules, sizeof *immediate);
 
-  rule_number r;
-  for (r = 0; r < nrules; ++r)
+  for (rule_number r = 0; r < nrules; ++r)
     {
       /* LHS of the rule R. */
       r1[r] = rules[r].lhs->number;
@@ -262,9 +256,8 @@ prepare_rules (void)
 static void
 prepare_states (void)
 {
-  state_number i;
   symbol_number *values = xnmalloc (nstates, sizeof *values);
-  for (i = 0; i < nstates; ++i)
+  for (state_number i = 0; i < nstates; ++i)
     values[i] = states[i]->accessing_symbol;
   muscle_insert_symbol_number_table ("stos", values,
                                      0, 1, nstates);
@@ -283,9 +276,9 @@ prepare_states (void)
 static int
 symbol_type_name_cmp (const symbol **lhs, const symbol **rhs)
 {
-  int res = uniqstr_cmp ((*lhs)->type_name, (*rhs)->type_name);
+  int res = uniqstr_cmp ((*lhs)->content->type_name, (*rhs)->content->type_name);
   if (!res)
-    res = (*lhs)->number - (*rhs)->number;
+    res = (*lhs)->content->number - (*rhs)->content->number;
   return res;
 }
 
@@ -312,16 +305,16 @@ symbols_by_type_name (void)
 static void
 type_names_output (FILE *out)
 {
-  int i;
   symbol **syms = symbols_by_type_name ();
   fputs ("m4_define([b4_type_names],\n[", out);
-  for (i = 0; i < nsyms; /* nothing */)
+  for (int i = 0; i < nsyms; /* nothing */)
     {
       /* The index of the first symbol of the current type-name.  */
       int i0 = i;
       fputs (i ? ",\n[" : "[", out);
-      for (; i < nsyms && syms[i]->type_name == syms[i0]->type_name; ++i)
-        fprintf (out, "%s%d", i != i0 ? ", " : "", syms[i]->number);
+      for (; i < nsyms
+           && syms[i]->content->type_name == syms[i0]->content->type_name; ++i)
+        fprintf (out, "%s%d", i != i0 ? ", " : "", syms[i]->content->number);
       fputs ("]", out);
     }
   fputs ("])\n\n", out);
@@ -336,9 +329,8 @@ type_names_output (FILE *out)
 static void
 symbol_numbers_output (FILE *out)
 {
-  int i;
   fputs ("m4_define([b4_symbol_numbers],\n[", out);
-  for (i = 0; i < nsyms; ++i)
+  for (int i = 0; i < nsyms; ++i)
     fprintf (out, "%s[%d]", i ? ", " : "", i);
   fputs ("])\n\n", out);
 }
@@ -351,14 +343,12 @@ symbol_numbers_output (FILE *out)
 static void
 user_actions_output (FILE *out)
 {
-  rule_number r;
-
   fputs ("m4_define([b4_actions], \n[", out);
-  for (r = 0; r < nrules; ++r)
+  for (rule_number r = 0; r < nrules; ++r)
     if (rules[r].action)
       {
-        fprintf (out, "b4_%scase(%d, [b4_syncline(%d, ",
-                 rules[r].is_predicate ? "predicate_" : "",
+        fprintf (out, "%s(%d, [b4_syncline(%d, ",
+                 rules[r].is_predicate ? "b4_predicate_case" : "b4_case",
                  r + 1, rules[r].action_location.start.line);
         string_output (out, rules[r].action_location.start.file);
         fprintf (out, ")\n[    %s]])\n\n", rules[r].action);
@@ -373,10 +363,9 @@ user_actions_output (FILE *out)
 static void
 merger_output (FILE *out)
 {
+  fputs ("m4_define([b4_mergers], \n[[", out);
   int n;
   merger_list* p;
-
-  fputs ("m4_define([b4_mergers], \n[[", out);
   for (n = 1, p = merge_functions; p != NULL; n += 1, p = p->next)
     {
       if (p->type[0] == '\0')
@@ -397,12 +386,10 @@ merger_output (FILE *out)
 static void
 prepare_symbol_definitions (void)
 {
-  int i;
-  for (i = 0; i < nsyms; ++i)
+  for (int i = 0; i < nsyms; ++i)
     {
       symbol *sym = symbols[i];
       const char *key;
-      const char *value;
 
 #define SET_KEY(Entry)                                          \
       obstack_printf (&format_obstack, "symbol(%d, %s)",        \
@@ -415,7 +402,7 @@ prepare_symbol_definitions (void)
       key = obstack_finish0 (&format_obstack);
 
       /* Whether the symbol has an identifier.  */
-      value = symbol_id_get (sym);
+      const char *value = symbol_id_get (sym);
       SET_KEY ("has_id");
       MUSCLE_INSERT_INT (key, !!value);
 
@@ -428,44 +415,42 @@ prepare_symbol_definitions (void)
       MUSCLE_INSERT_STRING (key, sym->tag);
 
       SET_KEY ("user_number");
-      MUSCLE_INSERT_INT (key, sym->user_token_number);
+      MUSCLE_INSERT_INT (key, sym->content->user_token_number);
 
       SET_KEY ("is_token");
       MUSCLE_INSERT_INT (key,
                          i < ntokens && sym != errtoken && sym != undeftoken);
 
       SET_KEY ("number");
-      MUSCLE_INSERT_INT (key, sym->number);
+      MUSCLE_INSERT_INT (key, sym->content->number);
 
       SET_KEY ("has_type");
-      MUSCLE_INSERT_INT (key, !!sym->type_name);
+      MUSCLE_INSERT_INT (key, !!sym->content->type_name);
 
       SET_KEY ("type");
-      MUSCLE_INSERT_STRING (key, sym->type_name ? sym->type_name : "");
+      MUSCLE_INSERT_STRING (key, sym->content->type_name
+                            ? sym->content->type_name : "");
 
-      {
-        int j;
-        for (j = 0; j < CODE_PROPS_SIZE; ++j)
-          {
-            /* "printer", not "%printer".  */
-            char const *pname = code_props_type_string (j) + 1;
-            code_props const *p = symbol_code_props_get (sym, j);
-            SET_KEY2 ("has", pname);
-            MUSCLE_INSERT_INT (key, !!p->code);
+      for (int j = 0; j < CODE_PROPS_SIZE; ++j)
+        {
+          /* "printer", not "%printer".  */
+          char const *pname = code_props_type_string (j) + 1;
+          code_props const *p = symbol_code_props_get (sym, j);
+          SET_KEY2 ("has", pname);
+          MUSCLE_INSERT_INT (key, !!p->code);
 
-            if (p->code)
-              {
-                SET_KEY2 (pname, "file");
-                MUSCLE_INSERT_STRING (key, p->location.start.file);
+          if (p->code)
+            {
+              SET_KEY2 (pname, "file");
+              MUSCLE_INSERT_C_STRING (key, p->location.start.file);
 
-                SET_KEY2 (pname, "line");
-                MUSCLE_INSERT_INT (key, p->location.start.line);
+              SET_KEY2 (pname, "line");
+              MUSCLE_INSERT_INT (key, p->location.start.line);
 
-                SET_KEY (pname);
-                MUSCLE_INSERT_STRING_RAW (key, p->code);
-              }
-          }
-      }
+              SET_KEY (pname);
+              MUSCLE_INSERT_STRING_RAW (key, p->code);
+            }
+        }
 #undef SET_KEY2
 #undef SET_KEY
     }
@@ -543,9 +528,6 @@ muscles_output (FILE *out)
 static void
 output_skeleton (void)
 {
-  int filter_fd[2];
-  pid_t pid;
-
   /* Compute the names of the package data dir and skeleton files.  */
   char const *m4 = (m4 = getenv ("M4")) ? m4 : M4;
   char const *datadir = pkgdatadir ();
@@ -573,6 +555,8 @@ output_skeleton (void)
      See the thread starting at
      <http://lists.gnu.org/archive/html/bug-bison/2008-07/msg00000.html>
      for details.  */
+  int filter_fd[2];
+  pid_t pid;
   {
     char const *argv[10];
     int i = 0;
